import numpy as np
import scipy.stats
import matplotlib.pyplot as plt


x = [4.3, 2.8, 3.9, 4.1, 9, 4.5, 3.3] # The dataset
samples = 10000  # Number of samples to use.
prior_mu, prior_sigma = 0, 5  # Parameters for the Normal prior.
p_cauchy = 0.01
likelihood_sigma = 0.5


def prx(x, mu):
    p1 = scipy.stats.norm.pdf(x, loc=mu, scale=likelihood_sigma)
    p2 = scipy.stats.cauchy.pdf(x)
    return np.prod((1-p_cauchy) * p1 + p_cauchy * p2)


mus = np.random.normal(loc=prior_mu, scale=prior_sigma, size=samples)
w = np.array([prx(x, mu) for mu in mus])
w = w / np.sum(w)

plt.hist(mus, weights=w, density=True, bins=np.linspace(2, 7, 100))
plt.show()
